jupyter_events: Jupyter Event System library
============================================

Description
-----------

Jupyter Event System library

License
-------

BSD 3-Clause License

Upstream Contact
----------------

https://pypi.org/project/jupyter-events/

